@@ -11,19 +11,15 @@ use URI;
 use URI::QueryParam;
 use URI::file;
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
-has dsn => sub {
-  my $uri = _uri_from_path(shift->_tempfile_path);
-  return "dbi:SQLite:uri=$uri";
-};
+has dsn => sub { _dsn_from_path(shift->_tempfile_path) };
 has max_connections => 5;
 has migrations      => sub {
   my $migrations = Mojo::SQLite::Migrations->new(sqlite => shift);
   weaken $migrations->{sqlite};
   return $migrations;
 };
-has [qw(password username)];
 has options => sub {
   {
     AutoCommit          => 1,
@@ -60,8 +56,7 @@ sub from_string {
   # Database file
   my $path = $uri->path;
   $path = $self->_tempfile_path if $path eq ':temp:';
-  my $new_uri = _uri_from_path($path);
-  my $dsn = "dbi:SQLite:uri=$new_uri";
+  my $dsn = _dsn_from_path($path);
 
   # Options
   my $options = $uri->query_form_hash;
@@ -75,13 +70,17 @@ sub new { @_ > 1 ? shift->SUPER::new->from_string(@_) : shift->SUPER::new }
 sub _dequeue {
   my $self = shift;
   while (my $dbh = shift @{$self->{queue} || []}) { return $dbh if $dbh->ping }
-  my $dbh = DBI->connect(map { $self->$_ } qw(dsn username password options));
-  $dbh->do('pragma journal_mode=WAL');
-  $dbh->do('pragma synchronous=NORMAL');
+  my $dbh = DBI->connect($self->dsn, undef, undef, $self->options);
+  if (defined $dbh) {
+    $dbh->do('pragma journal_mode=WAL');
+    $dbh->do('pragma synchronous=NORMAL');
+  }
   $self->emit(connection => $dbh);
   return $dbh;
 }
 
+sub _dsn_from_path { 'dbi:SQLite:uri=' . _uri_from_path(shift) }
+
 sub _enqueue {
   my ($self, $dbh) = @_;
   my $queue = $self->{queue} ||= [];
@@ -95,13 +94,7 @@ sub _tempfile_path {
   return URI::file->new($self->{tempfile}->filename)->path;
 };
 
-sub _uri_from_path {
-  my $path = shift;
-  my $uri = URI->new;
-  $uri->scheme('file');
-  $uri->path($path);
-  return $uri;
-}
+sub _uri_from_path { URI->new->Mojo::Base::tap(scheme => 'file')->Mojo::Base::tap(path => shift) }
 
 1;
 
@@ -291,7 +284,7 @@ separately.
   my $db = $sql->from_filename(':memory:')->db;
 
   # Additional options
-  $sql->from_filename($filename)->options({PrintError => 1});
+  $sql->from_filename($filename)->tap(sub { $_->options->{PrintError} = 1 });
 
 =head2 from_string
 
@@ -328,10 +321,7 @@ will be parsed and applied to L</"options">.
 
   # Additional options
   $sql->from_string('data.db?PrintError=1&sqlite_allow_multiple_statements=1');
-  
-  my $uri = URI::file->new($filename);
-  $uri->query_form_hash({PrintError => 1, sqlite_allow_multiple_statements => 1});
-  $sql->from_string($uri);
+  $sql->from_string(URI::file->new($filename)->Mojo::Base::tap(query_form_hash => {PrintError => 1}));
 
 =head2 new
 
